@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.59 2005/06/05 09:41:41 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.60.2.1 2006/01/13 11:46:45 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -58,6 +58,8 @@
 #include <nsIDOMAbstractView.h>
 #include <nsIDOMNSHTMLDocument.h>
 #include <nsIDOMNSUIEvent.h>
+#include <nsIDOMHTMLSelectElement.h>
+#include <nsIDOMHTMLIsIndexElement.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsITextToSubURI.h>
@@ -1014,6 +1016,13 @@ EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
 {
 	PRBool retval = PR_FALSE;
 
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aEvent));
+	NS_ENSURE_TRUE (nsEvent, retval);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return retval;
+
 	/* check for alt/ctrl */
 	PRBool isCtrl = PR_FALSE, isAlt = PR_FALSE;
 	aEvent->GetCtrlKey (&isCtrl);
@@ -1034,42 +1043,52 @@ EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
 	rv = aEvent->GetTarget (getter_AddRefs (target));
 	NS_ENSURE_SUCCESS (rv, retval);
 
-	nsCOMPtr<nsIDOMHTMLElement> element (do_QueryInterface (target, &rv));
-	NS_ENSURE_SUCCESS (rv, retval);
+	nsCOMPtr<nsIDOMHTMLInputElement> inputElement (do_QueryInterface (target));
+	if (inputElement)
+	{
+		nsEmbedString type;
+		inputElement->GetType (type);
 
-	PRUint16 type = 0;
-	element->GetNodeType(&type);
-	if (nsIDOMNode::ELEMENT_NODE != type) return retval;
+		nsEmbedCString (cType);
+		NS_UTF16ToCString (type, NS_CSTRING_ENCODING_UTF8, cType);
 
-	nsEmbedString uTag;
-	rv = element->GetLocalName(uTag);
-	NS_ENSURE_SUCCESS (rv, retval);
+		if (g_ascii_strcasecmp (cType.get(), "text") == 0 ||
+		    g_ascii_strcasecmp (cType.get(), "password") == 0 ||
+		    g_ascii_strcasecmp (cType.get(), "file") == 0) return retval;
+	}
 
-	nsEmbedCString tag;
-	NS_UTF16ToCString (uTag, NS_CSTRING_ENCODING_UTF8, tag);
+	nsCOMPtr<nsIDOMHTMLTextAreaElement> textArea;
+	nsCOMPtr<nsIDOMHTMLSelectElement> selectElement;
+	nsCOMPtr<nsIDOMHTMLIsIndexElement> indexElement;
 
-	if (g_ascii_strcasecmp (tag.get(), "input") == 0 ||
-	    g_ascii_strcasecmp (tag.get(), "textarea") == 0 ||
-	    g_ascii_strcasecmp (tag.get(), "select") == 0 ||
-	    g_ascii_strcasecmp (tag.get(), "button") == 0 ||
-	    g_ascii_strcasecmp (tag.get(), "isindex") == 0) return retval;
+	if ((textArea = do_QueryInterface (target)) ||
+	    (selectElement = do_QueryInterface (target)) ||
+	    (indexElement = do_QueryInterface (target))) return retval;
 
 	/* check for design mode */
+	nsCOMPtr<nsIDOMNode> node (do_QueryInterface (target, &rv));
+	NS_ENSURE_SUCCESS (rv, PR_FALSE);
+
 	nsCOMPtr<nsIDOMDocument> doc;
-	rv = element->GetOwnerDocument (getter_AddRefs (doc));
+	rv = node->GetOwnerDocument (getter_AddRefs (doc));
 	NS_ENSURE_SUCCESS (rv, retval);
 
-	nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (doc, &rv));
-	if (NS_FAILED (rv)) return retval; /* it's okay not to be a HTML document */
+	nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (doc));
+	if (htmlDoc)
+	{
+		nsEmbedString uDesign;
+		rv = htmlDoc->GetDesignMode (uDesign);
+		NS_ENSURE_SUCCESS (rv, retval);
 
-	nsEmbedString uDesign;
-	rv = htmlDoc->GetDesignMode (uDesign);
-	NS_ENSURE_SUCCESS (rv, retval);
+		nsEmbedCString design;
+		NS_UTF16ToCString (uDesign, NS_CSTRING_ENCODING_UTF8, design);
 
-	nsEmbedCString design;
-	NS_UTF16ToCString (uDesign, NS_CSTRING_ENCODING_UTF8, design);
-
-	retval = g_ascii_strcasecmp (design.get(), "on") != 0;
+		retval = g_ascii_strcasecmp (design.get(), "on") != 0;
+	}
+	else
+	{
+		retval = PR_TRUE;
+	}
 
 	return retval;
 }
